from django.apps import AppConfig


class VocabulariesConfig(AppConfig):
    name = "apis_core.apis_vocabularies"
